# -*- coding: utf-8 -*-

# source: https://github.com/cucumber/gherkin/blob/master/lib/gherkin/i18n.json

TRANSLATIONS = {
    "en": {
        "name": "English",
        "native": "English",
        "feature": "Feature|Business Need|Ability",
        "background": "Background",
        "scenario": "Scenario Outline|Scenario Template|Scenario",
        "examples": "Examples|Scenarios",
        "given": "Given",
        "when": "When",
        "then": "Then",
        "and": "And",
        "but": "But",
    },
    "af": {
        "name": "Afrikaans",
        "native": "Afrikaans",
        "feature": "Funksie|Besigheid Behoefte|Vermoë",
        "background": "Agtergrond",
        "scenario": "Situasie Uiteensetting|Situasie",
        "examples": "Voorbeelde",
        "given": "Gegewe",
        "when": "Wanneer",
        "then": "Dan",
        "and": "En",
        "but": "Maar",
    },
    "ar": {
        "name": "Arabic",
        "native": "العربية",
        "feature": "خاصية",
        "background": "الخلفية",
        "scenario": "سيناريو مخطط|سيناريو",
        "examples": "امثلة",
        "given": "بفرض",
        "when": "متى|عندما",
        "then": "اذاً|ثم",
        "and": "و",
        "but": "لكن",
    },
    "bm": {
        "name": "Malay",
        "native": "Bahasa Melayu",
        "feature": "Fungsi",
        "background": "Latar Belakang",
        "scenario": "Template Senario|Template Situai|Template Keadaan|Menggariskan Senario|Senario|Situai|Keadaan",
        "examples": "Contoh",
        "given": "Diberi|Bagi",
        "when": "Apabila",
        "then": "Maka|Kemudian",
        "and": "Dan",
        "but": "Tetapi|Tapi",
    },
    "bg": {
        "name": "Bulgarian",
        "native": "български",
        "feature": "Функционалност",
        "background": "Предистория",
        "scenario": "Рамка на сценарий|Сценарий",
        "examples": "Примери",
        "given": "Дадено",
        "when": "Когато",
        "then": "То",
        "and": "И",
        "but": "Но",
    },
    "ca": {
        "name": "Catalan",
        "native": "català",
        "background": "Rerefons|Antecedents",
        "feature": "Característica|Funcionalitat",
        "scenario": "Esquema de l'escenari|Escenari",
        "examples": "Exemples",
        "given": "Donat|Donada|Atès|Atesa",
        "when": "Quan",
        "then": "Aleshores|Cal",
        "and": "I",
        "but": "Però",
    },
    "cy-GB": {
        "name": "Welsh",
        "native": "Cymraeg",
        "background": "Cefndir",
        "feature": "Arwedd",
        "scenario": "Scenario Amlinellol|Scenario",
        "examples": "Enghreifftiau",
        "given": "Anrhegedig a",
        "when": "Pryd",
        "then": "Yna",
        "and": "A",
        "but": "Ond",
    },
    "cs": {
        "name": "Czech",
        "native": "Česky",
        "feature": "Požadavek",
        "background": "Pozadí|Kontext",
        "scenario": "Náčrt Scénáře|Osnova scénáře|Scénář",
        "examples": "Příklady",
        "given": "Pokud|Za předpokladu",
        "when": "Když",
        "then": "Pak",
        "and": "A také|A",
        "but": "Ale",
    },
    "da": {
        "name": "Danish",
        "native": "dansk",
        "feature": "Egenskab",
        "background": "Baggrund",
        "scenario": "Abstrakt Scenario|Scenarie",
        "examples": "Eksempler",
        "given": "Givet",
        "when": "Når",
        "then": "Så",
        "and": "Og",
        "but": "Men",
    },
    "de": {
        "name": "German",
        "native": "Deutsch",
        "feature": "Funktionalität",
        "background": "Grundlage",
        "scenario": "Szenariogrundriss|Szenario",
        "examples": "Beispiele",
        "given": "Angenommen|Gegeben sei|Gegeben seien",
        "when": "Wenn",
        "then": "Dann",
        "and": "Und",
        "but": "Aber",
    },
    "el": {
        "name": "Greek",
        "native": "Ελληνικά",
        "feature": "Δυνατότητα|Λειτουργία",
        "background": "Υπόβαθρο",
        "scenario": "Περιγραφή Σεναρίου|Σενάριο",
        "examples": "Παραδείγματα|Σενάρια",
        "given": "Δεδομένου",
        "when": "Όταν",
        "then": "Τότε",
        "and": "Και",
        "but": "Αλλά",
    },
    "en-au": {
        "name": "Australian",
        "native": "Australian",
        "feature": "Pretty much",
        "background": "First off",
        "scenario": "Reckon it's like|Awww, look mate",
        "examples": "You'll wanna",
        "given": "Y'know",
        "when": "It's just unbelievable",
        "then": "But at the end of the day I reckon",
        "and": "Too right",
        "but": "Yeah nah",
    },
    "en-Scouse": {
        "name": "Scouse",
        "native": "Scouse",
        "feature": "Feature",
        "background": "Dis is what went down",
        "scenario": "Wharrimean is|The thing of it is",
        "examples": "Examples",
        "given": "Givun|Youse know when youse got",
        "when": "Wun|Youse know like when",
        "then": "Dun|Den youse gotta",
        "and": "An",
        "but": "Buh",
    },
    "en-tx": {
        "name": "Texan",
        "native": "Texan",
        "feature": "Feature",
        "background": "Background",
        "scenario": "All y'all|Scenario",
        "examples": "Examples",
        "given": "Given y'all",
        "when": "When y'all",
        "then": "Then y'all",
        "and": "And y'all",
        "but": "But y'all",
    },
    "eo": {
        "name": "Esperanto",
        "native": "Esperanto",
        "feature": "Trajto",
        "background": "Fono",
        "scenario": "Konturo de la scenaro|Scenaro",
        "examples": "Ekzemploj",
        "given": "Donitaĵo",
        "when": "Se",
        "then": "Do",
        "and": "Kaj",
        "but": "Sed",
    },
    "es": {
        "name": "Spanish",
        "native": "español",
        "background": "Antecedentes",
        "feature": "Característica",
        "scenario": "Esquema del escenario|Escenario",
        "examples": "Ejemplos",
        "given": "Dado|Dada|Dados|Dadas",
        "when": "Cuando",
        "then": "Entonces",
        "and": "Y",
        "but": "Pero",
    },
    "et": {
        "name": "Estonian",
        "native": "eesti keel",
        "feature": "Omadus",
        "background": "Taust",
        "scenario": "Raamstsenaarium|Stsenaarium",
        "examples": "Juhtumid",
        "given": "Eeldades",
        "when": "Kui",
        "then": "Siis",
        "and": "Ja",
        "but": "Kuid",
    },
    "fa": {
        "name": "Persian",
        "native": "فارسی",
        "feature": "وِیژگی",
        "background": "زمینه",
        "scenario": "الگوی سناریو|سناریو",
        "examples": "نمونه ها",
        "given": "با فرض",
        "when": "هنگامی",
        "then": "آنگاه",
        "and": "و",
        "but": "اما",
    },
    "fi": {
        "name": "Finnish",
        "native": "suomi",
        "feature": "Ominaisuus",
        "background": "Tausta",
        "scenario": "Tapausaihio|Tapaus",
        "examples": "Tapaukset",
        "given": "Oletetaan",
        "when": "Kun",
        "then": "Niin",
        "and": "Ja",
        "but": "Mutta",
    },
    "fr": {
        "name": "French",
        "native": "français",
        "feature": "Fonctionnalité",
        "background": "Contexte",
        "scenario": "Plan du scénario|Plan du Scénario|Scénario",
        "examples": "Exemples",
        "given": "Soit|Etant donné|Etant donnée|Etant donnés|Etant données|Étant donné|Étant donnée|Étant donnés|Étant données",
        "when": "Quand|Lorsque|Lorsqu'<",
        "then": "Alors",
        "and": "Et",
        "but": "Mais",
    },
    "gl": {
        "name": "Galician",
        "native": "galego",
        "background": "Contexto",
        "feature": "Característica",
        "scenario": "Esbozo do escenario|Escenario",
        "examples": "Exemplos",
        "given": "Dado|Dada|Dados|Dadas",
        "when": "Cando",
        "then": "Entón|Logo",
        "and": "E",
        "but": "Mais|Pero",
    },
    "he": {
        "name": "Hebrew",
        "native": "עברית",
        "feature": "תכונה",
        "background": "רקע",
        "scenario": "תבנית תרחיש|תרחיש",
        "examples": "דוגמאות",
        "given": "בהינתן",
        "when": "כאשר",
        "then": "אז|אזי",
        "and": "וגם",
        "but": "אבל",
    },
    "hi": {
        "name": "Hindi",
        "native": "हिंदी",
        "feature": "रूप लेख",
        "background": "पृष्ठभूमि",
        "scenario": "परिदृश्य रूपरेखा|परिदृश्य",
        "examples": "उदाहरण",
        "given": "अगर|यदि|चूंकि",
        "when": "जब|कदा",
        "then": "तब|तदा",
        "and": "और|तथा",
        "but": "पर|परन्तु|किन्तु",
    },
    "hr": {
        "name": "Croatian",
        "native": "hrvatski",
        "feature": "Osobina|Mogućnost|Mogucnost",
        "background": "Pozadina",
        "scenario": "Skica|Koncept|Scenarij",
        "examples": "Primjeri|Scenariji",
        "given": "Zadan|Zadani|Zadano",
        "when": "Kada|Kad",
        "then": "Onda",
        "and": "I",
        "but": "Ali",
    },
    "ht": {
        "name": "Creole",
        "native": "kreyòl",
        "feature": "Karakteristik|Mak|Fonksyonalite",
        "background": "Kontèks|Istorik",
        "scenario": "Plan senaryo|Plan Senaryo|Senaryo deskripsyon|Senaryo Deskripsyon|Dyagram senaryo|Dyagram Senaryo|Senaryo",
        "examples": "Egzanp",
        "given": "Sipoze|Sipoze ke|Sipoze Ke",
        "when": "Lè|Le",
        "then": "Lè sa a|Le sa a",
        "and": "Ak|Epi|E",
        "but": "Men",
    },
    "hu": {
        "name": "Hungarian",
        "native": "magyar",
        "feature": "Jellemző",
        "background": "Háttér",
        "scenario": "Forgatókönyv vázlat|Forgatókönyv",
        "examples": "Példák",
        "given": "Amennyiben|Adott",
        "when": "Majd|Ha|Amikor",
        "then": "Akkor",
        "and": "És",
        "but": "De",
    },
    "id": {
        "name": "Indonesian",
        "native": "Bahasa Indonesia",
        "feature": "Fitur",
        "background": "Dasar",
        "scenario": "Skenario konsep|Skenario",
        "examples": "Contoh",
        "given": "Dengan",
        "when": "Ketika",
        "then": "Maka",
        "and": "Dan",
        "but": "Tapi",
    },
    "is": {
        "name": "Icelandic",
        "native": "Íslenska",
        "feature": "Eiginleiki",
        "background": "Bakgrunnur",
        "scenario": "Lýsing Atburðarásar|Lýsing Dæma|Atburðarás",
        "examples": "Dæmi|Atburðarásir",
        "given": "Ef",
        "when": "Þegar",
        "then": "Þá",
        "and": "Og",
        "but": "En",
    },
    "it": {
        "name": "Italian",
        "native": "italiano",
        "feature": "Funzionalità",
        "background": "Contesto",
        "scenario": "Schema dello scenario|Scenario",
        "examples": "Esempi",
        "given": "Dato|Data|Dati|Date",
        "when": "Quando",
        "then": "Allora",
        "and": "E",
        "but": "Ma",
    },
    "ja": {
        "name": "Japanese",
        "native": "日本語",
        "feature": "フィーチャ|機能",
        "background": "背景",
        "scenario": "シナリオアウトライン|シナリオテンプレート|テンプレ|シナリオテンプレ|シナリオ",
        "examples": "例|サンプル",
        "given": "前提<",
        "when": "もし<",
        "then": "ならば<",
        "and": "かつ<",
        "but": "しかし<|但し<|ただし<",
    },
    "jv": {
        "name": "Javanese",
        "native": "Basa Jawa",
        "feature": "Fitur",
        "background": "Dasar",
        "scenario": "Konsep skenario|Skenario",
        "examples": "Conto|Contone",
        "given": "Nalika|Nalikaning",
        "when": "Manawa|Menawa",
        "then": "Njuk|Banjur",
        "and": "Lan",
        "but": "Tapi|Nanging|Ananging",
    },
    "kn": {
        "name": "Kannada",
        "native": "ಕನ್ನಡ",
        "background": "ಹಿನ್ನೆಲೆ",
        "feature": "ಹೆಚ್ಚಳ",
        "scenario": "ವಿವರಣೆ|ಕಥಾಸಾರಾಂಶ",
        "examples": "ಉದಾಹರಣೆಗಳು",
        "given": "ನೀಡಿದ",
        "when": "ಸ್ಥಿತಿಯನ್ನು",
        "then": "ನಂತರ",
        "and": "ಮತ್ತು",
        "but": "ಆದರೆ",
    },
    "ko": {
        "name": "Korean",
        "native": "한국어",
        "background": "배경",
        "feature": "기능",
        "scenario": "시나리오 개요|시나리오",
        "examples": "예",
        "given": "조건<|먼저<",
        "when": "만일<|만약<",
        "then": "그러면<",
        "and": "그리고<",
        "but": "하지만<|단<",
    },
    "lt": {
        "name": "Lithuanian",
        "native": "lietuvių kalba",
        "feature": "Savybė",
        "background": "Kontekstas",
        "scenario": "Scenarijaus šablonas|Scenarijus",
        "examples": "Pavyzdžiai|Scenarijai|Variantai",
        "given": "Duota",
        "when": "Kai",
        "then": "Tada",
        "and": "Ir",
        "but": "Bet",
    },
    "lu": {
        "name": "Luxemburgish",
        "native": "Lëtzebuergesch",
        "feature": "Funktionalitéit",
        "background": "Hannergrond",
        "scenario": "Plang vum Szenario|Szenario",
        "examples": "Beispiller",
        "given": "ugeholl",
        "when": "wann",
        "then": "dann",
        "and": "an|a",
        "but": "awer|mä",
    },
    "lv": {
        "name": "Latvian",
        "native": "latviešu",
        "feature": "Funkcionalitāte|Fīča",
        "background": "Konteksts|Situācija",
        "scenario": "Scenārijs pēc parauga|Scenārijs",
        "examples": "Piemēri|Paraugs",
        "given": "Kad",
        "when": "Ja",
        "then": "Tad",
        "and": "Un",
        "but": "Bet",
    },
    "nl": {
        "name": "Dutch",
        "native": "Nederlands",
        "feature": "Functionaliteit",
        "background": "Achtergrond",
        "scenario": "Abstract Scenario|Scenario",
        "examples": "Voorbeelden",
        "given": "Gegeven|Stel",
        "when": "Als",
        "then": "Dan",
        "and": "En",
        "but": "Maar",
    },
    "no": {
        "name": "Norwegian",
        "native": "norsk",
        "feature": "Egenskap",
        "background": "Bakgrunn",
        "scenario": "Scenariomal|Abstrakt Scenario|Scenario",
        "examples": "Eksempler",
        "given": "Gitt",
        "when": "Når",
        "then": "Så",
        "and": "Og",
        "but": "Men",
    },
    "pa": {
        "name": "Panjabi",
        "native": "ਪੰਜਾਬੀ",
        "feature": "ਖਾਸੀਅਤ|ਮੁਹਾਂਦਰਾ|ਨਕਸ਼ ਨੁਹਾਰ",
        "background": "ਪਿਛੋਕੜ",
        "scenario": "ਪਟਕਥਾ ਢਾਂਚਾ|ਪਟਕਥਾ ਰੂਪ ਰੇਖਾ|ਪਟਕਥਾ",
        "examples": "ਉਦਾਹਰਨਾਂ",
        "given": "ਜੇਕਰ|ਜਿਵੇਂ ਕਿ",
        "when": "ਜਦੋਂ",
        "then": "ਤਦ",
        "and": "ਅਤੇ",
        "but": "ਪਰ",
    },
    "pl": {
        "name": "Polish",
        "native": "polski",
        "feature": "Właściwość|Funkcja|Aspekt|Potrzeba biznesowa",
        "background": "Założenia",
        "scenario": "Szablon scenariusza|Scenariusz",
        "examples": "Przykłady",
        "given": "Zakładając(?:,? że)?|Mając",
        "when": "Jeżeli|Jeśli|Gdy|Kiedy",
        "then": "Wtedy",
        "and": "Oraz|I",
        "but": "Ale",
    },
    "pt": {
        "name": "Portuguese",
        "native": "português",
        "background": "Contexto|Cenário de Fundo|Cenario de Fundo|Fundo",
        "feature": "Funcionalidade|Característica|Caracteristica",
        "scenario": "Esquema do Cenário|Esquema do Cenario|Delineação do Cenário|Delineacao do Cenario|Cenário|Cenario",
        "examples": "Exemplos|Cenários|Cenarios",
        "given": "Dado|Dada|Dados|Dadas",
        "when": "Quando",
        "then": "Então|Entao",
        "and": "E",
        "but": "Mas",
    },
    "ro": {
        "name": "Romanian",
        "native": "română",
        "background": "Context",
        "feature": "Functionalitate|Funcționalitate|Funcţionalitate",
        "scenario": "Structura scenariu|Structură scenariu|Scenariu",
        "examples": "Exemple",
        "given": "Date fiind|Dat fiind|Dati fiind|Dați fiind|Daţi fiind",
        "when": "Cand|Când",
        "then": "Atunci",
        "and": "Si|Și|Şi",
        "but": "Dar",
    },
    "ru": {
        "name": "Russian",
        "native": "русский",
        "feature": "Функция|Функционал|Свойство",
        "background": "Предыстория|Контекст",
        "scenario": "Структура сценария|Сценарий",
        "examples": "Примеры",
        "given": "Допустим|Дано|Пусть",
        "when": "Если|Когда",
        "then": "То|Тогда",
        "and": "И|К тому же|Также",
        "but": "Но|А",
    },
    "sv": {
        "name": "Swedish",
        "native": "Svenska",
        "feature": "Egenskap",
        "background": "Bakgrund",
        "scenario": "Abstrakt Scenario|Scenariomall|Scenario",
        "examples": "Exempel",
        "given": "Givet",
        "when": "När",
        "then": "Så",
        "and": "Och",
        "but": "Men",
    },
    "sk": {
        "name": "Slovak",
        "native": "Slovensky",
        "feature": "Požiadavka|Funkcia|Vlastnosť",
        "background": "Pozadie",
        "scenario": "Náčrt Scenáru|Náčrt Scenára|Osnova Scenára|Scenár",
        "examples": "Príklady",
        "given": "Pokiaľ|Za predpokladu",
        "when": "Keď|Ak",
        "then": "Tak|Potom",
        "and": "A|A tiež|A taktiež|A zároveň",
        "but": "Ale",
    },
    "sl": {
        "name": "Slovenian",
        "native": "Slovenski",
        "feature": "Funkcionalnost|Funkcija|Možnosti|Moznosti|Lastnost|Značilnost",
        "background": "Kontekst|Osnova|Ozadje",
        "scenario": "Struktura scenarija|Skica|Koncept|Oris scenarija|Osnutek|Scenarij|Primer",
        "examples": "Primeri|Scenariji",
        "given": "Dano|Podano|Zaradi|Privzeto",
        "when": "Ko|Ce|Če|Kadar",
        "then": "Nato|Potem|Takrat",
        "and": "In|Ter",
        "but": "Toda|Ampak|Vendar",
    },
    "sr-Latn": {
        "name": "Serbian (Latin)",
        "native": "Srpski (Latinica)",
        "feature": "Funkcionalnost|Mogućnost|Mogucnost|Osobina",
        "background": "Kontekst|Osnova|Pozadina",
        "scenario": "Struktura scenarija|Skica|Koncept|Scenario|Primer",
        "examples": "Primeri|Scenariji",
        "given": "Zadato|Zadate|Zatati",
        "when": "Kada|Kad",
        "then": "Onda",
        "and": "I",
        "but": "Ali",
    },
    "sr-Cyrl": {
        "name": "Serbian",
        "native": "Српски",
        "feature": "Функционалност|Могућност|Особина",
        "background": "Контекст|Основа|Позадина",
        "scenario": "Структура сценарија|Скица|Концепт|Сценарио|Пример",
        "examples": "Примери|Сценарији",
        "given": "Задато|Задате|Задати",
        "when": "Када|Кад",
        "then": "Онда",
        "and": "И",
        "but": "Али",
    },
    "tl": {
        "name": "Telugu",
        "native": "తెలుగు",
        "feature": "గుణము",
        "background": "నేపథ్యం",
        "scenario": "కథనం|సన్నివేశం",
        "examples": "ఉదాహరణలు",
        "given": "చెప్పబడినది",
        "when": "ఈ పరిస్థితిలో",
        "then": "అప్పుడు",
        "and": "మరియు",
        "but": "కాని",
    },
    "th": {
        "name": "Thai",
        "native": "ไทย",
        "feature": "โครงหลัก|ความต้องการทางธุรกิจ|ความสามารถ",
        "background": "แนวคิด",
        "scenario": "สรุปเหตุการณ์|โครงสร้างของเหตุการณ์|เหตุการณ์",
        "examples": "ชุดของตัวอย่าง|ชุดของเหตุการณ์",
        "given": "กำหนดให้",
        "when": "เมื่อ",
        "then": "ดังนั้น",
        "and": "และ",
        "but": "แต่",
    },
    "tlh": {
        "name": "Klingon",
        "native": "tlhIngan",
        "feature": "Qap|Qu'meH 'ut|perbogh|poQbogh malja'|laH",
        "background": "mo'",
        "scenario": "lut chovnatlh|lut",
        "examples": "ghantoH|lutmey",
        "given": "ghu' noblu'|DaH ghu' bejlu'",
        "when": "qaSDI'",
        "then": "vaj",
        "and": "'ej|latlh",
        "but": "'ach|'a",
    },
    "tr": {
        "name": "Turkish",
        "native": "Türkçe",
        "feature": "Özellik",
        "background": "Geçmiş",
        "scenario": "Senaryo taslağı|Senaryo",
        "examples": "Örnekler",
        "given": "Diyelim ki",
        "when": "Eğer ki",
        "then": "O zaman",
        "and": "Ve",
        "but": "Fakat|Ama",
    },
    "tt": {
        "name": "Tatar",
        "native": "Татарча",
        "feature": "Мөмкинлек|Үзенчәлеклелек",
        "background": "Кереш",
        "scenario": "Сценарийның төзелеше|Сценарий",
        "examples": "Үрнәкләр|Мисаллар",
        "given": "Әйтик",
        "when": "Әгәр",
        "then": "Нәтиҗәдә",
        "and": "Һәм|Вә",
        "but": "Ләкин|Әмма",
    },
    "uk": {
        "name": "Ukrainian",
        "native": "Українська",
        "feature": "Функціонал",
        "background": "Передумова",
        "scenario": "Структура сценарію|Сценарій",
        "examples": "Приклади",
        "given": "Припустимо|Припустимо, що|Нехай|Дано",
        "when": "Якщо|Коли",
        "then": "То|Тоді",
        "and": "І|А також|Та",
        "but": "Але",
    },
    "uz": {
        "name": "Uzbek",
        "native": "Узбекча",
        "feature": "Функционал",
        "background": "Тарих",
        "scenario": "Сценарий структураси|Сценарий",
        "examples": "Мисоллар",
        "given": "Агар",
        "when": "Агар",
        "then": "Унда",
        "and": "Ва",
        "but": "Лекин|Бирок|Аммо",
    },
    "vi": {
        "name": "Vietnamese",
        "native": "Tiếng Việt",
        "feature": "Tính năng",
        "background": "Bối cảnh",
        "scenario": "Khung tình huống|Khung kịch bản|Tình huống|Kịch bản",
        "examples": "Dữ liệu",
        "given": "Biết|Cho",
        "when": "Khi",
        "then": "Thì",
        "and": "Và",
        "but": "Nhưng",
    },
    "zh-CN": {
        "name": "Chinese simplified",
        "native": "简体中文",
        "feature": "功能",
        "background": "背景",
        "scenario": "场景大纲|剧本大纲|场景|剧本",
        "examples": "例子",
        "given": "假如<|假设<|假定<",
        "when": "当<",
        "then": "那么<",
        "and": "而且<|并且<|同时<",
        "but": "但是<",
    },
    "zh-TW": {
        "name": "Chinese traditional",
        "native": "繁體中文",
        "feature": "功能",
        "background": "背景",
        "scenario": "場景大綱|劇本大綱|場景|劇本",
        "examples": "例子",
        "given": "假如<|假設<|假定<",
        "when": "當<",
        "then": "那麼<",
        "and": "而且<|並且<|同時<",
        "but": "但是<",
    },
    "ur": {
        "name": "Urdu",
        "native": "اردو",
        "feature": "صلاحیت|کاروبار کی ضرورت|خصوصیت",
        "background": "پس منظر",
        "scenario": "منظر نامے کا خاکہ|منظرنامہ",
        "examples": "مثالیں",
        "given": "اگر|بالفرض|فرض کیا",
        "when": "جب",
        "then": "پھر|تب",
        "and": "اور",
        "but": "لیکن",
    },
}
